@@ -16,7 +16,7 @@ public:
 
 void vregs_HACK_info::add_registers(VregsRegInfo* reginfop)
 {
-    cout << "vregs_spec_RegInfo Init\n";
+    COUT << "vregs_spec_RegInfo Init\n";
 
     reginfop->add_register (0x1010, 4, "Reg_at_0x1010");
     reginfop->add_register (0x1040, 4, "Reg_at_0x1040");
@@ -37,14 +37,14 @@ int main()
     reginfop->dump();
 
     VregsRegEntry* entp = reginfop->find_by_addr(0x1040);
-    if (!entp) { cout << "find_by_addr failed\n"; return (10); }
+    if (!entp) { COUT << "find_by_addr failed\n"; return (10); }
 
     //reginfop->print_at_addr (0x1040);
-    cout << "address 0010 is: " << reginfop->addr_name(0x0010, buf,1000) << endl;
-    cout << "address 1010 is: " << reginfop->addr_name(0x1010, buf,1000) << endl;
-    cout << "address 1040 is: " << reginfop->addr_name(0x1040, buf,1000) << endl;
-    cout << "address 2013 is: " << reginfop->addr_name(0x2013, buf,1000) << endl;
-    cout << "address 3013 is: " << reginfop->addr_name(0x3013, buf,1000) << endl;
+    COUT << "address 0010 is: " << reginfop->addr_name(0x0010, buf,1000) << endl;
+    COUT << "address 1010 is: " << reginfop->addr_name(0x1010, buf,1000) << endl;
+    COUT << "address 1040 is: " << reginfop->addr_name(0x1040, buf,1000) << endl;
+    COUT << "address 2013 is: " << reginfop->addr_name(0x2013, buf,1000) << endl;
+    COUT << "address 3013 is: " << reginfop->addr_name(0x3013, buf,1000) << endl;
 
     return (0);
 }
